Name:           virt-who
Version:        0.9
Release:        6%{?dist}
Summary:        Agent for reporting virtual guest IDs to subscription-manager

Group:          System Environment/Base
License:        GPLv2+
URL:            https://fedorahosted.org/virt-who/
Source0:        https://fedorahosted.org/releases/v/i/virt-who/%{name}-%{version}.tar.gz
BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

BuildArch:      noarch
BuildRequires:  python2-devel
Requires:       libvirt-python
# python-rhsm 1.10.10 has required call for guestId support
Requires:       python-rhsm >= 1.10.10
# python-suds is required for vSphere support
Requires:       python-suds
# m2crypto is required for Hyper-V support
Requires:       m2crypto
Requires(post): chkconfig
Requires(preun): chkconfig
# This is for /sbin/service
Requires(preun): initscripts

# Make sure that virt-who ends cleanly on sigint/sigterm signal
Patch0:         virt-who-0.9-end-cleanly-on-sigint-sigterm-signal.patch
# Report guest attributes to the SAM
Patch1:         virt-who-0.9-support-for-sending-guest-attributes.patch
# Fix dying when system is unregistered
Patch2:         virt-who-0.9-fix-dying-on-unregistration.patch
# Fix that virt-who can't be stopped using CTRL+C
Patch3:         virt-who-0.9-fix-ctrl-c.patch
# Fix that older libvirt doesn't have state() method implemented
Patch4:         virt-who-0.9-fix-domain-state.patch


%description
Agent that collects information about virtual guests present in the system and
report them to the subscription manager.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build


%install
rm -rf $RPM_BUILD_ROOT

make DESTDIR=$RPM_BUILD_ROOT install
mkdir -p %{buildroot}/%{_sharedstatedir}/%{name}

# Don't run test suite in check section, because it need the system to be
# registered to subscription-manager server

%clean
rm -rf $RPM_BUILD_ROOT

%post
# This adds the proper /etc/rc*.d links for the script
/sbin/chkconfig --add virt-who

%preun
if [ $1 -eq 0 ] ; then
    /sbin/service virt-who stop >/dev/null 2>&1
    /sbin/chkconfig --del virt-who
fi

%postun
if [ "$1" -ge "1" ] ; then
    /sbin/service virt-who condrestart >/dev/null 2>&1 || :
fi


%files
%doc README README.hyperv LICENSE
%{_bindir}/virt-who
%{_datadir}/virt-who/
%{_sysconfdir}/rc.d/init.d/virt-who
%attr(600, root, root) %config(noreplace) %{_sysconfdir}/sysconfig/virt-who
%{_mandir}/man8/virt-who.8.gz
%{_sharedstatedir}/%{name}


%changelog
* Mon Aug 04 2014 Radek Novacek <rnovacek@redhat.com> 0.9-6
- Fix that older libvirt doesn't have state() method implemented
- Resolves: rhbz#1124732

* Thu Jun 19 2014 Radek Novacek <rnovacek@redhat.com> 0.9-5
- Fix that virt-who can't be stopped using CTRL+C
- Resolves: rhbz#1092818

* Thu May 22 2014 Radek Novacek <rnovacek@redhat.com> 0.9-4
- Increase required version of python-rhsm to 1.10.10
- Fix incompatibilities with python 2.4 and older libvirt
- Resolves: rhbz#1095597

* Thu May 22 2014 Radek Novacek <rnovacek@redhat.com> 0.9-3
- Make sure that virt-who ends cleanly on sigint/sigterm signal
- Report guest attributes to the SAM
- Fix dying when system is unregistered
- Resolves: rhbz#1092811, rhbz#1095597, rhbz#1092848

* Thu Apr 17 2014 Radek Novacek <rnovacek@redhat.com> 0.9-2
- Change permission of config file from 644 to 600
- Resolves: rhbz#1088756

* Wed Mar 12 2014 Radek Novacek <rnovacek@redhat.com> 0.9-1
- Rebase to 0.9
- Remove dependency on libvirt package
- Resolves: rhbz#993822, rhbz#975340, rhbz#861552

* Thu Oct 04 2012 Radek Novacek <rnovacek@redhat.com> 0.7-9
- Create PID file ASAP to prevent service stop fails
- Resolves: rhbz#861563

* Mon Sep 24 2012 Radek Novacek <rnovacek@redhat.com> 0.7-8
- Apply previous patch

* Mon Sep 24 2012 Radek Novacek <rnovacek@redhat.com> 0.7-7
- Don't crash in vdsm mode
- Resolves: rhbz#859841

* Mon Sep 17 2012 Radek Novacek <rnovacek@redhat.com> 0.7-6
- Increase required python-rhsm version to 1.0.4
- Add virt-who manual page
- Resolves: rhbz#848781

* Mon Sep 03 2012 Radek Novacek <rnovacek@redhat.com> 0.7-5
- Fix crash when running virt-who in interval mode
- Resolves: rhbz#848777, rhbz#853371

* Fri Aug 24 2012 Radek Novacek <rnovacek@redhat.com> 0.7-4
- Don't start event loop when not running in background mode
- Don't use deprecated way for reading certificates
- Resolves: rhbz#848777

* Thu Aug 23 2012 Radek Novacek <rnovacek@redhat.com> 0.7-3
- Fix "--interval" option
- Resolves: rhbz#849921

* Tue Aug 07 2012 Radek Novacek <rnovacek@redhat.com> 0.7-2
- Don't register domain events in one-shot mode
- Resolves: rhbz#808061

* Mon Jul 16 2012 Radek Novacek <rnovacek@redhat.com> 0.7-1
- Upstream version 0.7
- RFE: command line improvements
- Cleanup PID file on unexpected termination
- Reload configuration on SIGHUP signal
- Resolves: rhbz#808061, rhbz#806226

* Fri Jan 20 2012 Radek Novacek <rnovacek@redhat.com> 0.5-5
- Fix crash when no guest exists
- Resolves: rhbz#783355

* Wed Jan 11 2012 Radek Novacek <rnovacek@redhat.com> 0.5-4
- Make password for ESX not mandatory
- Assume using https protocol when not given on ESX
- Resolves: rhbz#772612, rhbz#772379

* Wed Dec 21 2011 Radek Novacek <rnovacek@redhat.com> 0.5-3
- Fix logging exceptions
- Fix using undefined variable
- Don't report Domain-0 as guest
- Resolves: rhbz#768112, rhbz#769170

* Wed Dec 14 2011 Radek Novacek <rnovacek@redhat.com> 0.5-2
- Fix refernce before assignment error
- Resolves: rhbz#756380

* Tue Dec 13 2011 Radek Novacek <rnovacek@redhat.com> 0.5-1
- Upstream version 0.5
- vSphere support
- Don't print logs to stderr when not in debug mode
- Add workaround for xen for adding guests
- Fix exporting variables from /etc/sysconfig in initscript
- Resolves: rhbz#759631, rhbz#765728, rhbz#761569, rhbz#756380

* Wed Nov 30 2011 Radek Novacek <rnovacek@redhat.com> 0.4-1
- Upstream version 0.4
- Make main loop more robust
- Workaround for removing machines using xen
- Add vdsm mode
- Resolves: rhbz#756380, rhbz#757974, rhbz#754330

* Tue Nov 08 2011 Radek Novacek <rnovacek@redhat.com> 0.3-3
- Use updateConsumer API instead of updateConsumerFact (fixes limit 255 chars of uuid list)
- Requires python-rhsm >= 0.96.13
- Resolves: rhbz#749514

* Mon Oct 10 2011 Radek Novacek <rnovacek@redhat.com> 0.3-2.1
- Rebase RHEL-5 version to RHEL-6 version
- Related: rhbz#725839

* Wed Sep 07 2011 Radek Novacek <rnovacek@redhat.com> - 0.3-2
- Add upstream patch that prevents failure when server not implements /status/ command

* Thu Sep 01 2011 Radek Novacek <rnovacek@redhat.com> - 0.3-1
- Add initscript and configuration file

* Mon Aug 22 2011 Radek Novacek <rnovacek@redhat.com> - 0.2-2
- Bump release because of tagging in wrong branch

* Mon Aug 22 2011 Radek Novacek <rnovacek@redhat.com> - 0.2-1
- Update to upstream version 0.2
- Add Requires: libvirt

* Fri Aug 19 2011 Radek Novacek <rnovacek@redhat.com> - 0.1-2
- Add BuildRoot tag (the package will be in RHEL5)

* Wed Aug 10 2011 Radek Novacek <rnovacek@redhat.com> - 0.1-1
- initial import
